use chrono::NaiveDateTime;
use serde::{Deserialize, Serialize};
use sqlx::PgPool;
use sqlx::types::chrono;
use crate::db_result::CountResult;

#[derive(Debug, Clone, Deserialize, Default, Serialize)]
pub struct Feedback {
    pub id: i64,
    pub user_id: i64,
    pub content: String,
    pub created_at: NaiveDateTime,
}

impl Feedback {
    pub async fn search_feedback(page: i64, page_size: i64, db_pool: &PgPool) -> Result<Vec<Feedback>, sqlx::Error> {
        sqlx::query_as!(
            Feedback,
            r#"select id, user_id, content, created_at from feedback limit $1 offset $2"#,
            page_size, page
        ).fetch_all(db_pool).await
    }

    pub async fn count_feedback(db_pool: &PgPool) -> Result<CountResult, sqlx::Error> {
        sqlx::query_as!(
            CountResult,
            r#"select count(*) from feedback"#,
        ).fetch_one(db_pool).await
    }

    pub async fn add_feedback(feedback: &mut Feedback, db_pool: &PgPool) -> Result<Feedback, sqlx::Error> {
        feedback.created_at = chrono::Local::now().naive_local();
        sqlx::query_as!(
            Feedback,
            r#"insert into feedback
            (user_id, content, created_at)
            values
            ($1, $2, $3) returning *
            "#,
            feedback.user_id,
            feedback.content,
            feedback.created_at
        ).fetch_one(db_pool).await
    }
}